==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/pt_BR.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Pesquisa de uso",
    "Sent on: {on}" : "Enviado em: {on}",
    "An error occurred while sending your report." : "Erro ao enviar seu relatório.",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Lista de aplicativos <em>(para cada aplicativo: nome, versão, habilitado?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente do banco de dados <em>(tipo, versão, tamanho do banco de dados)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informação de criptografia <em>(está habilitado?, qual é o módulo padrão?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de compartilhamentos <em>(por tipo e configuração de permissão)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versão, limite de memória, tempo máx. execução, tamanho máx. de arquivo)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Detalhes do servidor <em>(versão, memcache usado, bloqueio/previsualização/avatar habilitado?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de: arquivos, usuários, armazenamento por tipo, comentários e etiquetas)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Você quer ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso? Você pode desabilitar isso em qualquer momento nas configurações administrativas.",
    "Not now" : "Agora não",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados sobre sua instalação e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Levamos sua privacidade muito a sério. O envio de dados está desabilitado por padrão e você pode escolher ativá-lo. Eles serão tornados anônimos e lhe será dada a opção de escolher o que compartilhar. Quando o servidor recebe um relatório, os anteriores são removidos. Envie um relatório vazio para excluir todos os dados atualmente armazenados no servidor.",
    "Send new report now" : "Enviar novo relatório agora",
    "Send usage survey monthly" : "Enviar mensalmente a pesquisa de uso",
    "Data to send" : "Dados a enviar",
    "Last report" : "Último relatório",
    "Sent on: %s" : "Enviado em: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Levamos sua privacidade muito a sério. Os dados são tornados anônimos e você pode habilitar/desabilitar isso a qualquer momento e por padrão está sempre desabilitado. Abaixo você pode ajustar quais dados serão enviados e ver o último relatório enviado. Quando o servidor recebe um novo relatório seu, todos os relatórios anteriores são removidos. Se você desabilitar uma das configurações abaixo, você pode enviar um novo relatório o qual irá excluir os dados que estão atualmente armazenados no servidor.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Levamos sua privacidade muito a sério. Os dados são tornados anônimos e você pode habilitar/desabilitar isso a qualquer momento e por padrão está sempre desabilitado. Abaixo você pode ajustar quais dados serão enviados e ver o último relatório enviado. Quando o servidor recebe um novo relatório seu, todos os relatórios anteriores são removidos. Se você desabilitar uma das configurações abaixo, você pode enviar um novo relatório o qual irá excluir os dados que estão atualmente armazenados no servidor."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/pt_BR.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Pesquisa de uso",
    "Sent on: {on}" : "Enviado em: {on}",
    "An error occurred while sending your report." : "Erro ao enviar seu relatório.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicativos <em>(para cada aplicativo: nome, versão, status de habilitado)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Ambiente do banco de dados <em>(tipo, versão, tamanho do banco de dados)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informação de criptografia <em>(está habilitado?, qual é o módulo padrão?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de compartilhamentos <em>(por tipo e configuração de permissão)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Ambiente PHP <em>(versão, limite de memória, tempo máx. execução, tamanho máx. de arquivo)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalhes do servidor <em>(versão, cache de memória usado, status de bloqueio/visualizações/avatares)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de: arquivos, usuários, armazenamento por tipo, comentários e etiquetas)</em>",
    "Help improve Nextcloud" : "Ajude a melhorar o Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Você quer ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso? Você pode desabilitar isso em qualquer momento nas configurações administrativas.",
    "Not now" : "Agora não",
    "Send usage" : "Enviar uso",
    "Never" : "Nunca",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados sobre sua instalação e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Levamos sua privacidade muito a sério. O envio de dados está desabilitado por padrão e você pode escolher ativá-lo. Eles serão tornados anônimos e lhe será dada a opção de escolher o que compartilhar. Quando o servidor recebe um relatório, os anteriores são removidos. Envie um relatório vazio para excluir todos os dados atualmente armazenados no servidor.",
    "Send new report now" : "Enviar novo relatório agora",
    "Send usage survey monthly" : "Enviar mensalmente a pesquisa de uso",
    "Data to send" : "Dados a enviar",
    "Last report" : "Último relatório",
    "Sent on: %s" : "Enviado em: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Lista de aplicativos <em>(para cada aplicativo: nome, versão, habilitado?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Detalhes do servidor <em>(versão, memcache usado, bloqueio/previsualização/avatar habilitado?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Levamos sua privacidade muito a sério. Os dados são tornados anônimos e você pode habilitar/desabilitar isso a qualquer momento e por padrão está sempre desabilitado. Abaixo você pode ajustar quais dados serão enviados e ver o último relatório enviado. Quando o servidor recebe um novo relatório seu, todos os relatórios anteriores são removidos. Se você desabilitar uma das configurações abaixo, você pode enviar um novo relatório o qual irá excluir os dados que estão atualmente armazenados no servidor.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Você pode ajudar a melhorar o Nextcloud enviando dados anônimos sobre sua instalação e uso.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Levamos sua privacidade muito a sério. Os dados são tornados anônimos e você pode habilitar/desabilitar isso a qualquer momento e por padrão está sempre desabilitado. Abaixo você pode ajustar quais dados serão enviados e ver o último relatório enviado. Quando o servidor recebe um novo relatório seu, todos os relatórios anteriores são removidos. Se você desabilitar uma das configurações abaixo, você pode enviar um novo relatório o qual irá excluir os dados que estão atualmente armazenados no servidor."
},
"nplurals=2; plural=(n > 1);");
